@@ -71,10 +71,10 @@ import com.openexchange.dav.DAVProtocol;
 import com.openexchange.dav.resources.DAVCollection;
 import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.FolderService;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.tasks.TasksSQLImpl;
 import com.openexchange.server.ServiceLookup;
-import com.openexchange.tools.session.SessionHolder;
+import com.openexchange.session.SessionHolder;
+import com.openexchange.user.User;
 import com.openexchange.user.UserService;
 import com.openexchange.webdav.protocol.Multistatus;
 import com.openexchange.webdav.protocol.Protocol;
@@ -97,6 +97,7 @@ public class GroupwareCaldavFactory extends DAVFactory {
     private final ICalEmitter icalEmitter;
     private final ICalParser icalParser;
     private final UserService users;
+    private final ConfigViewFactory configViewFactory;
 
     /**
      * Initializes a new {@link GroupwareCaldavFactory}.
@@ -111,11 +112,12 @@ public class GroupwareCaldavFactory extends DAVFactory {
         this.icalEmitter = services.getService(ICalEmitter.class);
         this.icalParser = services.getService(ICalParser.class);
         this.users = services.getService(UserService.class);
+        this.configViewFactory = services.getService(ConfigViewFactory.class);
     }
 
     @Override
     public String getURLPrefix() {
-        return "/caldav/";
+        return getURLPrefix("/caldav/");
     }
 
     @Override
@@ -271,5 +273,9 @@ public class GroupwareCaldavFactory extends DAVFactory {
     public User resolveUser(int userID) throws OXException {
         return users.getUser(userID, getContext());
     }
+    
+    public ConfigViewFactory getConfigViewFactory() {
+        return configViewFactory;
+    }
 
 }
