@@ -53,14 +53,17 @@ import static com.openexchange.chronos.provider.CalendarFolderProperty.USED_FOR_
 import static com.openexchange.chronos.provider.CalendarFolderProperty.optPropertyValue;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Set;
 import com.openexchange.caldav.GroupwareCaldavFactory;
 import com.openexchange.caldav.Tools;
+import com.openexchange.caldav.mixins.CalendarOrder;
 import com.openexchange.caldav.mixins.ScheduleDefaultCalendarURL;
 import com.openexchange.caldav.mixins.ScheduleDefaultTasksURL;
 import com.openexchange.caldav.mixins.ScheduleInboxURL;
 import com.openexchange.caldav.mixins.ScheduleOutboxURL;
 import com.openexchange.caldav.mixins.SupportedCalendarComponentSets;
 import com.openexchange.caldav.mixins.SupportedReportSet;
+import com.openexchange.chronos.provider.CalendarCapability;
 import com.openexchange.dav.DAVProtocol;
 import com.openexchange.dav.DAVUserAgent;
 import com.openexchange.dav.Privilege;
@@ -68,7 +71,6 @@ import com.openexchange.dav.mixins.CurrentUserPrivilegeSet;
 import com.openexchange.dav.resources.DAVCollection;
 import com.openexchange.dav.resources.DAVRootCollection;
 import com.openexchange.dav.resources.FolderCollection;
-import com.openexchange.dav.resources.PlaceholderCollection;
 import com.openexchange.exception.OXException;
 import com.openexchange.folderstorage.CalendarFolderConverter;
 import com.openexchange.folderstorage.ContentType;
@@ -80,11 +82,9 @@ import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.calendar.contentType.CalendarContentType;
 import com.openexchange.folderstorage.database.contentType.TaskContentType;
-import com.openexchange.folderstorage.mail.contentType.TrashContentType;
 import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.folderstorage.type.PublicType;
 import com.openexchange.folderstorage.type.SharedType;
-import com.openexchange.groupware.container.CommonObject;
 import com.openexchange.groupware.userconfiguration.UserPermissionBits;
 import com.openexchange.login.Interface;
 import com.openexchange.tools.session.ServerSessionAdapter;
@@ -99,14 +99,8 @@ import com.openexchange.webdav.protocol.WebdavResource;
  */
 public class CalDAVRootCollection extends DAVRootCollection {
 
-    /**
-     * The reserved tree identifier for MS Outlook folder tree: <code>"1"</code>.
-     * (copied from com.openexchange.folderstorage.outlook)
-     */
-    private static final String OUTLOOK_TREE_ID = "1";
-
     private final GroupwareCaldavFactory factory;
-    private String trashFolderID;
+
     private List<UserizedFolder> subfolders;
     private String treeID;
 
@@ -118,9 +112,11 @@ public class CalDAVRootCollection extends DAVRootCollection {
     public CalDAVRootCollection(GroupwareCaldavFactory factory) {
         super(factory, "Calendars");
         this.factory = factory;
-        super.includeProperties(
+        includeProperties(
             new SupportedCalendarComponentSets(SupportedCalendarComponentSets.VEVENT, SupportedCalendarComponentSets.VTODO),
-            new ScheduleDefaultCalendarURL(factory), new ScheduleDefaultTasksURL(factory), new SupportedReportSet(),
+            new ScheduleDefaultCalendarURL(factory),
+            new ScheduleDefaultTasksURL(factory),
+            new SupportedReportSet(),
             new CurrentUserPrivilegeSet(Privilege.READ, Privilege.READ_ACL, Privilege.READ_CURRENT_USER_PRIVILEGE_SET, Privilege.BIND, Privilege.UNBIND)
         );
     }
@@ -177,24 +173,29 @@ public class CalDAVRootCollection extends DAVRootCollection {
                 }
             }
             LOG.debug("{}: child collection '{}' not found, creating placeholder collection", getUrl(), name);
-            return new PlaceholderCollection<CommonObject>(factory, constructPathForChildResource(name), CalendarContentType.getInstance(), getTreeID());
+            return new CalDAVPlaceholderCollection<>(factory, constructPathForChildResource(name), CalendarContentType.getInstance(), getTreeID());
         } catch (OXException e) {
             throw DAVProtocol.protocolException(getUrl(), e);
         }
     }
 
     private FolderCollection<?> createCollection(UserizedFolder folder) throws OXException {
-        return createCollection(folder, CalDAVFolderCollection.NO_ORDER);
+        return createCollection(folder, CalendarOrder.NO_ORDER);
     }
 
     private FolderCollection<?> createCollection(UserizedFolder folder, int order) throws OXException {
         if (TaskContentType.getInstance().equals(folder.getContentType())) {
             return factory.mixin(new TaskCollection(factory, constructPathForChildResource(folder), folder, order));
         } else if (CalendarContentType.getInstance().equals(folder.getContentType())) {
-            return factory.mixin(new EventCollection(factory, constructPathForChildResource(folder), folder, order));
-        } else {
-            throw new UnsupportedOperationException("content type " + folder.getContentType() + " not supported");
+            if (folder.getSupportedCapabilities().contains(CalendarCapability.SYNC.getName())) {
+                return factory.mixin(new EventCollection(factory, constructPathForChildResource(folder), folder, order));
+            }
+            if (folder.getSupportedCapabilities().contains(CalendarCapability.CTAG.getName())) {
+                return factory.mixin(new CTagEventCollection(factory, constructPathForChildResource(folder), folder, order));
+            }
+            throw new UnsupportedOperationException("Folder " + folder.getID() + " is not available via CalDAV.");
         }
+        throw new UnsupportedOperationException("content type " + folder.getContentType() + " not supported");
     }
 
     @Override
@@ -211,7 +212,7 @@ public class CalDAVRootCollection extends DAVRootCollection {
         }
         children.add(new ScheduleOutboxCollection(factory));
         children.add(new ScheduleInboxCollection(factory));
-        LOG.debug("{}: got {} child resources.", getUrl(), children.size());
+        LOG.debug("{}: got {} child resources.", getUrl(), Integer.valueOf(children.size()));
         return children;
     }
 
@@ -269,8 +270,7 @@ public class CalDAVRootCollection extends DAVRootCollection {
      */
     private List<UserizedFolder> getSynchronizedFolders(Type type, ContentType contentType) throws OXException {
         List<UserizedFolder> folders = new ArrayList<UserizedFolder>();
-        FolderResponse<UserizedFolder[]> visibleFoldersResponse = getFolderService().getVisibleFolders(
-                getTreeID(), contentType, type, false, factory.getSession(), null);
+        FolderResponse<UserizedFolder[]> visibleFoldersResponse = getFolderService().getVisibleFolders(getTreeID(), contentType, type, false, factory.getSession(), null);
         UserizedFolder[] response = visibleFoldersResponse.getResponse();
         for (UserizedFolder folder : response) {
             if (isUsedForSync(folder)) {
@@ -286,67 +286,20 @@ public class CalDAVRootCollection extends DAVRootCollection {
      * @param folder The folder to check
      * @return <code>true</code> if the folder should be considered for synchronization, <code>false</code>, otherwise
      */
-    private boolean isUsedForSync(UserizedFolder folder) throws OXException {
+    private boolean isUsedForSync(UserizedFolder folder) {
         if (Permission.READ_OWN_OBJECTS > folder.getOwnPermission().getReadPermission()) {
             return false;
         }
-        if (isTrashFolder(folder)) {
-            return false;
+        if (CalendarContentType.getInstance().equals(folder.getContentType())) {
+            Set<String> caps = folder.getSupportedCapabilities();
+            if (!caps.contains(CalendarCapability.SYNC.getName()) && !caps.contains(CalendarCapability.CTAG.getName())) {
+                return false;
+            }
         }
         Object value = optPropertyValue(CalendarFolderConverter.getExtendedProperties(folder), USED_FOR_SYNC_LITERAL);
         return null == value || Boolean.parseBoolean(String.valueOf(value));
     }
 
-    /**
-     * Gets the id of the default trash folder
-     *
-     * @return
-     */
-    private String getTrashFolderID() {
-        if (null == trashFolderID) {
-            try {
-                trashFolderID = getFolderService().getDefaultFolder(factory.getUser(), OUTLOOK_TREE_ID,
-                        TrashContentType.getInstance(), factory.getSession(), null).getID();
-            } catch (OXException e) {
-                LOG.warn("unable to determine default trash folder", e);
-            }
-        }
-        return this.trashFolderID;
-    }
-
-    /**
-     * Checks whether the supplied folder is a trash folder, i.e. one of it's parent folders is the default trash folder.
-     * <p/>
-     * Only applicable when using the {@link #OUTLOOK_TREE_ID}.
-     *
-     * @param folder The folder to check
-     * @return <code>true</code> if the folder is a trash folder, <code>false</code>, otherwise
-     * @throws OXException
-     */
-    private boolean isTrashFolder(UserizedFolder folder) throws OXException {
-        if (OUTLOOK_TREE_ID.equals(getTreeID()) && PrivateType.getInstance().equals(folder.getType()) &&
-            ServerSessionAdapter.valueOf(factory.getSession()).getUserPermissionBits().hasOLOX20()) {
-            String trashFolderId = this.getTrashFolderID();
-            if (null != trashFolderId) {
-                if (trashFolderId.equals(folder.getParentID())) {
-                    return true;
-                }
-                FolderResponse<UserizedFolder[]> pathResponse = getFolderService().getPath(
-                        OUTLOOK_TREE_ID, folder.getID(), this.factory.getSession(), null);
-                UserizedFolder[] response = pathResponse.getResponse();
-                for (UserizedFolder parentFolder : response) {
-                    if (trashFolderId.equals(parentFolder.getID())) {
-                        LOG.debug("Detected folder below trash: {}", folder);
-                        return true;
-                    }
-                }
-            } else {
-                LOG.warn("No config value for trash folder id found");
-            }
-        }
-        return false;
-    }
-
     /**
      * Gets the used folder tree identifier.
      *
