@@ -170,6 +170,11 @@ public class ScheduleInboxCollection extends DAVCollection implements FilteringR
         return new Date(0);
     }
 
+    @Override
+    public String getSyncToken() throws WebdavProtocolException {
+        return "0";
+    }
+
     @Override
     public AbstractResource getChild(String name) throws WebdavProtocolException {
         return new ScheduleInboxResource(getFactory(), constructPathForChildResource(name));
