@@ -149,7 +149,7 @@ public class Tools {
 	public static int parse(final String id) throws OXException {
 		try {
 			return Integer.parseInt(id);
-		} catch (final NumberFormatException e) {
+		} catch (NumberFormatException e) {
 			throw ContactExceptionCodes.ID_PARSING_FAILED.create(e, id);
 		}
 	}
