@@ -52,7 +52,7 @@ package com.openexchange.carddav.photos;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.dav.DAVFactory;
 import com.openexchange.server.ServiceLookup;
-import com.openexchange.tools.session.SessionHolder;
+import com.openexchange.session.SessionHolder;
 import com.openexchange.webdav.protocol.Protocol;
 import com.openexchange.webdav.protocol.WebdavCollection;
 import com.openexchange.webdav.protocol.WebdavPath;
@@ -104,7 +104,7 @@ public class PhotoFactory extends DAVFactory {
 
     @Override
     public String getURLPrefix() {
-        return "/photos/";
+        return getURLPrefix("/photos/");
     }
 
 }
