@@ -53,11 +53,11 @@ import java.util.Map;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 import com.openexchange.groupware.contexts.Context;
-import com.openexchange.groupware.ldap.User;
 import com.openexchange.java.Strings;
 import com.openexchange.session.Session;
+import com.openexchange.session.SessionHolder;
 import com.openexchange.tools.session.ServerSession;
-import com.openexchange.tools.session.SessionHolder;
+import com.openexchange.user.User;
 import com.openexchange.webdav.action.AbstractAction;
 import com.openexchange.webdav.action.ServletWebdavRequest;
 import com.openexchange.webdav.action.ServletWebdavResponse;
