@@ -86,7 +86,7 @@ public abstract class DAVProtocol extends Protocol {
     /** HTTP/1.1 507 Insufficient Storage */
     public static final int SC_INSUFFICIENT_STORAGE = 507;
 
-    private static org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DAVProtocol.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(DAVProtocol.class);
 
     @Override
     public WebdavAction getReportAction(String namespace, String name) {
@@ -174,9 +174,8 @@ public abstract class DAVProtocol extends Protocol {
     public static WebdavProtocolException protocolException(WebdavPath url, Exception e) {
         if (OXException.class.isInstance(e)) {
             return protocolException(url, e, getStatusCode(((OXException) e).getCategory()));
-        } else {
-            return protocolException(url, e, HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
         }
+        return protocolException(url, e, HttpServletResponse.SC_INTERNAL_SERVER_ERROR);
     }
 
     /**
