@@ -68,6 +68,8 @@ public enum DAVUserAgent {
     CARDDAV_SYNC("CardDAV-Sync on Android (CardDAV)"),
     SMOOTH_SYNC("SmoothSync on Android (CalDAV/CardDAV)"),
     DAVDROID("DAVdroid on Android (CalDAV/CardDAV)"),
+    DAVX5("DAVx\u2075 on Android (CalDAV/CardDAV)"),
+    OUTLOOK_CALDAV_SYNCHRONIZER("Outlook CalDav Synchronizer (CalDAV/CardDAV)"),
     WINDOWS_PHONE("Windows Phone Contacts and Calendar (CalDAV/CardDAV)"),
     WINDOWS("Windows Contacts and Calendar (CalDAV/CardDAV)"),
     GENERIC_CALDAV("Sync Client (CalDAV)"),
@@ -110,15 +112,21 @@ public enum DAVUserAgent {
             if (userAgent.contains("SmoothSync")) {
                 return SMOOTH_SYNC;
             }
+            if (userAgent.contains("DAVx5")) {
+                return DAVUserAgent.DAVX5;
+            }
             if (userAgent.contains("DAVdroid")) {
                 return DAVUserAgent.DAVDROID;
             }
-            if (userAgent.contains("Lightning") && userAgent.contains("Thunderbird") && userAgent.contains("Mozilla")) {
+            if (userAgent.contains("Thunderbird") && userAgent.contains("Mozilla")) {
                 return THUNDERBIRD_LIGHTNING;
             }
             if (userAgent.contains("iOS") && userAgent.contains("dataaccessd") && false == userAgent.contains("Android")) {
                 return IOS;
             }
+            if (userAgent.contains("CalDavSynchronizer")) {
+                return OUTLOOK_CALDAV_SYNCHRONIZER;
+            }
             if (userAgent.startsWith("MSFT-WP")) {
                 return WINDOWS_PHONE;
             }
@@ -129,7 +137,7 @@ public enum DAVUserAgent {
                 (userAgent.contains("CalendarStore") || (userAgent.contains("CalendarAgent")))) {
                 return MAC_CALENDAR;
             }
-            if ((userAgent.contains("Mac OS") || userAgent.contains("Mac_OS")) &&
+            if ((userAgent.contains("Mac OS") || userAgent.contains("Mac_OS") || userAgent.contains("macOS")) &&
                 (userAgent.contains("AddressBook"))) {
                 return MAC_CONTACTS;
             }
