@@ -49,6 +49,8 @@
 
 package com.openexchange.dav.mixins;
 
+import static com.openexchange.dav.DAVTools.getExternalPath;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.dav.DAVProtocol;
 import com.openexchange.dav.resources.FolderCollection;
 import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;
@@ -62,20 +64,23 @@ import com.openexchange.webdav.protocol.helpers.SingleXMLPropertyMixin;
 public class ShareResourceURI extends SingleXMLPropertyMixin {
 
     private final FolderCollection<?> collection;
+    private ConfigViewFactory configViewFactory;
 
     /**
      * Initializes a new {@link Invite}.
      *
      * @param collection The collection
+     * @param configViewFactory The {@link ConfigViewFactory}
      */
-    public ShareResourceURI(FolderCollection<?> collection) {
+    public ShareResourceURI(FolderCollection<?> collection, ConfigViewFactory configViewFactory) {
         super(DAVProtocol.DAV_NS.getURI(), "share-resource-uri");
         this.collection = collection;
+        this.configViewFactory = configViewFactory;
     }
 
     @Override
     protected String getValue() {
-        return "<D:href>" + collection.getUrl() + "</D:href>";
+        return "<D:href>" + getExternalPath(configViewFactory, collection.getUrl().toString()) + "</D:href>";
     }
 
 }
