@@ -51,9 +51,11 @@ package com.openexchange.dav.principals.resources;
 
 import com.openexchange.chronos.CalendarUserType;
 import com.openexchange.chronos.ResourceId;
+import com.openexchange.config.cascade.ConfigViewFactory;
 import com.openexchange.dav.DAVFactory;
 import com.openexchange.dav.mixins.CalendarUserAddressSet;
 import com.openexchange.dav.mixins.DisplayName;
+import com.openexchange.dav.mixins.EmailAddressSet;
 import com.openexchange.dav.mixins.PrincipalURL;
 import com.openexchange.dav.mixins.RecordType;
 import com.openexchange.dav.resources.DAVResource;
@@ -76,13 +78,15 @@ public class ResourcePrincipalResource extends DAVResource {
      *
      * @param factory The factory
      * @param resource The resource
+     * @param url The WebDAV path of the resource
      */
-    public ResourcePrincipalResource(DAVFactory factory, Resource resource) {
-        super(factory, new WebdavPath("principals", "resources", String.valueOf(resource.getIdentifier())));
+    public ResourcePrincipalResource(DAVFactory factory, Resource resource, WebdavPath url) {
+        super(factory, url);
         this.resource = resource;
+        ConfigViewFactory configViewFactory = factory.getService(ConfigViewFactory.class);
         includeProperties(new DisplayName(resource.getDisplayName()), new com.openexchange.dav.mixins.CalendarUserType(CalendarUserType.RESOURCE),
-            new RecordType(RecordType.RECORD_TYPE_RESOURCES), new PrincipalURL(resource.getIdentifier(), CalendarUserType.RESOURCE),
-            new CalendarUserAddressSet(factory.getContext().getContextId(), resource),
+            new RecordType(RecordType.RECORD_TYPE_RESOURCES), new PrincipalURL(resource.getIdentifier(), CalendarUserType.RESOURCE, configViewFactory),
+            new CalendarUserAddressSet(factory.getContext().getContextId(), resource, configViewFactory), new EmailAddressSet(resource),
             new com.openexchange.dav.mixins.ResourceId(ResourceId.forResource(factory.getContext().getContextId(), resource.getIdentifier()))
         );
     }
